========================================
``psyclone.tests.core.access_type_test``
========================================

.. automodule:: psyclone.tests.core.access_type_test

   .. contents::
      :local:

.. currentmodule:: psyclone.tests.core.access_type_test
